=======
Changelog
=======


0.2.0 (2020-09-11)
------------------

* Fix potentially wrong plotting of significance bars if not all categories had significant differences.
* Add ability to further customize plots using keyword arguments to seaborn functions.
* Add option to mark non-significant comparisons


0.1.0 (2020-09-08)
------------------

* First working skeleton.
